#
# spec file for package ecj
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global eclipse_ver 4.23
%global bundle_ver 3.29.0
%global jar_ver %{eclipse_ver}
%global drop R-%{jar_ver}-202203080310
Name:           ecj
Version:        %{eclipse_ver}
Release:        4.2
Summary:        Eclipse Compiler for Java
License:        EPL-2.0 AND GPL-2.0-only WITH Classpath-exception-2.0
Group:          Development/Libraries/Java
URL:            https://www.eclipse.org
Source0:        https://download.eclipse.org/eclipse/downloads/drops4/%{drop}/ecjsrc-%{jar_ver}.jar
Source1:        https://repo1.maven.org/maven2/org/eclipse/jdt/ecj/%{bundle_ver}/ecj-%{bundle_ver}.pom
# Extracted from https://download.eclipse.org/eclipse/downloads/drops4/%%{drop}/ecj-%%{jar_ver}.jar
Source2:        MANIFEST.MF
Patch0:         ecj-rpmdebuginfo.patch
Patch1:         ecj-java8compat.patch
BuildRequires:  ant
BuildRequires:  java-devel >= 11
BuildRequires:  javapackages-local >= 6
BuildRequires:  unzip
BuildArch:      noarch

%description
ECJ is the Java bytecode compiler of the Eclipse Platform.  It is also known as
the JDT Core batch compiler.

%prep
%setup -q -c
%patch -P 0 -p1
%patch -P 1 -p1

# Specify encoding
sed -i -e '/compilerarg/s/Xlint:none/Xlint:none -encoding cp1252/' build.xml

mkdir -p scripts/binary/META-INF/
cp %{SOURCE2} scripts/binary/META-INF/MANIFEST.MF

%build
%{ant}

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 ecj.jar %{buildroot}%{_javadir}/%{name}/ecj.jar
install -pm 0644 javax17api.jar %{buildroot}%{_javadir}/%{name}/javax17api.jar

# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} %{SOURCE1} %{buildroot}%{_mavenpomdir}/%{name}/ecj.pom
%add_maven_depmap %{name}/ecj.pom %{name}/ecj.jar -a "org.eclipse.jdt:core,org.eclipse.jdt.core.compiler:ecj,org.eclipse.tycho:org.eclipse.jdt.core,org.eclipse.tycho:org.eclipse.jdt.compiler.apt"
%add_maven_depmap org.eclipse:javax17api:17 %{name}/javax17api.jar -a "org.eclipse:java9api,org.eclipse:java10api:org.eclipse:java15api"

# Install the ecj wrapper script
%jpackage_script org.eclipse.jdt.internal.compiler.batch.Main '' '' ecj ecj true

# Install manpage
mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 -p ecj.1 %{buildroot}%{_mandir}/man1/ecj.1

%files -f .mfiles
%license about.html
%{_bindir}/ecj
%{_mandir}/man1/ecj*

%changelog
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Feb 13 2024 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * ecj-java8compat.patch
    + Allow building ecj with language levels 8 (bsc#1219862)
- Distribute the bundled javax17api.jar under maven coordinate of
  org.eclipse:javax17api:17, so that it can be used if needed
* Mon Aug 21 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to eclipse 4.23 ecj (jsc#PED-2979)
  * No changelog was made available.
- Use the bundled javax17api.jar stubs, but don't distribute
  them
- Removed patches:
  * encoding.patch
    + handled by a simple sed run
  * javaAPI.patch
    + not needed with this version
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * encoding.patch
    + the encoding needs to be set for all JDK versions
- Modified patch:
  * ecj-rpmdebuginfo.patch
    + rediff
  * javaAPI.patch
    + extract the encoding part to a separate patch
* Mon Oct 18 2021 Marcel Witte <wittemar@googlemail.com>
- Upgrade to eclipse 4.18 ecj
  * No changelog was made available.
- Switch java14api to java15api to be compatible to JDK 15
* Mon Oct 18 2021 Marcel Witte <wittemar@googlemail.com>
- Upgrade to eclipse 4.17 ecj
  * No changelog was made available.
- Removed patches:
  * ecj-encoding.patch
  * jdk10u-jdk8compat.patch
- Switch to JDK 11 for build a JDK 8 is not supported anymore by ecj
- Switch java10api to java14api to be compatible to JDK 14
* Wed Sep 25 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to eclipse 4.12 ecj
  * No changelog was made available.
- Removed patches:
  * ecj-include-props.patch,
  * eclipse-gcj-compat4.2.1.patch
  * eclipse-gcj-nodummysymbol.patch
    + Unneeded for this version
- Added patches:
  * ecj-encoding.patch
    + Fix build with java >= 9
  * javaAPI.patch
    + When building with java < 9, add the java10api.jar and the
    JRE's rt.jar to bootclasspath
  * jdk10u-jdk8compat.patch
    + Patch out deprecation annotation not understood by the JDK
    when building with java < 9
- Build the java.compiler module's javax.* packages as non-modular
  java10api.jar, so that ecj can be compiled even with java < 9
- Distribute the java10api artifact for packages that might need
  it
* Thu Nov 22 2018 Fridrich Strba <fstrba@suse.com>
- Add one more maven artifact alias:
  * org.eclipse.tycho:org.eclipse.jdt.compiler.apt
* Mon Oct 29 2018 Fridrich Strba <fstrba@suse.com>
- Add two more maven artifact aliases:
  * org.eclipse.jdt.core.compiler:ecj
  * org.eclipse.jdt:ecj
* Mon Sep 18 2017 fstrba@suse.com
- Don't build against the java-bootstrap package; it is gone
* Fri May 19 2017 tchvatal@suse.com
- Fix build with javapackages-tools
* Thu Sep 10 2015 tchvatal@suse.com
- Fix cycles on Leap which is 1315 same as SLE.
- Sort deps with spec-cleaner
* Fri Sep 19 2014 dmacvicar@suse.de
- avoid cycles in Factory with Java 8
* Thu Sep 18 2014 dmacvicar@suse.de
- Remove upstream git URL for MANIFEST.MF as it is not
  versioned. File will change and Factory bots will
  complain.
* Thu Sep 18 2014 dmacvicar@suse.de
- restore bootstrap dependencies
- Restored patches and GCJ Main, as they are used
  to bootstrap other packages.
  * eclipse-gcj-compat4.2.1.patch
  * eclipse-gcj-nodummysymbol.patch
- Removed obsolete ecj-native, as old SUSE package did
  not had it and no package provides it
* Wed Sep 17 2014 dmacvicar@suse.de
- clean spec file
* Mon Sep 15 2014 dmacvicar@suse.de
- export NO_BRP_CHECK_BYTECODE_VERSION
* Mon Sep 15 2014 dmacvicar@suse.de
- Update to ecj 4.2.1 (expected by tomcat 7.0.55+)
- Sync with Fedora ecj-4.4
- Drop gcj patches
  * eclipse-gcj-nodummysymbol.patch
- Drop obsolete patches
  * ecj-generatedebuginfo.patch : now done in spec
  * eclipse-gcj-compat4.2.1.patch
  * ecj-defaultto1.5.patch : we can use 1.6
* Wed Sep  3 2014 tchvatal@suse.com
- Spec-cleaner
- BuildIgnore java-devel pkgs to avoid conflicts
* Wed Sep  3 2014 coolo@suse.com
- on 13.2 and Factory build against bootstrap java
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri May 31 2013 varkoly@suse.com
- Fix the spec to avoid fileconflicts with ecj-bootstrap
* Mon Jan 21 2013 mvyskocil@suse.com
- Update to ecj 4.2.1 (expected by tomcat 7.0.34+)
  (no changelog provided, but it's normal for eclipse)
- sync with fedora 4.2.1-3
  * ecj-defaultto1.5.patch - change the default -source to 1.5 to
    match gcc-java capabilities
  * ecj-generatedebuginfo.patch - generate debug info for java sources
  * ecj-include-props.patch - package .props files too
  * ecj-rpmdebuginfo.patch - hack, force debuginfo to be created when
    RPM_BUILD_ROOT variable is defined
  * eclipse-gcj-compat4.2.1.patch - disable all expected warning
  * eclipse-gcj-nodummysymbol.patch - don't generate dummy entry in jars
  * eclipse-jpackage-changelog.txt
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Thu Nov 22 2007 anosek@suse.cz
- new package, initial version 3.3
